pub struct SimRunner<const N: usize, const Q: usize> { /* private fields */ }Expand description
Implementations
Sourceimpl<const N: usize, const Q: usize> SimRunner<N, Q>
impl<const N: usize, const Q: usize> SimRunner<N, Q>
pub fn new(bus: SimBus<N, Q>) -> Self
Sourcepub fn tick(
&mut self,
nodes: &mut [&mut dyn SimNodeErased<N, Q>],
duration: Duration,
) -> usize
pub fn tick( &mut self, nodes: &mut [&mut dyn SimNodeErased<N, Q>], duration: Duration, ) -> usize
Ticks the simulation by duration microseconds, routing all delivered messages to their
destination nodes and collecting their responses back onto the bus.
Returns the number of messages delivered in this tick.
pub fn bus(&mut self) -> &mut SimBus<N, Q>