CanBusState

Enum CanBusState 

pub enum CanBusState {
    Active,
    ErrorPassive,
    BusOff {
        since: Instant,
    },
}

Variants



Active

Bus is operational - frames are delivered normally.



ErrorPassive

Bus is in error-passive state - frames may still be delivered but error counts are elevated.



BusOff

Bus-off - no frames are delivered until the bus is reset.

Fields

since: Instant

Implementations